
import { Base64 } from 'js-base64'
import request, { BASE_URL } from '@/utils/request'
import { getToken, setToken } from '@/utils/token'

// 获取当前用户信息
export const getCurrentUser = () => {
  const { access_token } = getToken() || {}
  return request.get('/api/v5/user', { params: { access_token } })
}

// 登录
export const signIn = (data) => {
  return request.post('/oauth/token', data, { contentType: 'application/x-www-form-urlencoded' }).then(res => {
    setToken(res)
    return res;
  })
}

// 刷新 token
export const refreshToken = (token) => {
  const { refresh_token } = token || {}
  return request.post('/oauth/token', null, { params: { grant_type: 'refresh_token', refresh_token } }).then(res => {
    setToken(res)
    return res
  })
}

// 获取仓库信息
export const getRepo = (user, repo = 'my-note') => {
  const { access_token } = getToken() || {}
  return request.get(`/api/v5/repos/${user.login}/${repo}`, { params: { access_token } })
}

// 新建仓库
export const newRepo = (name = 'my-note') => {
  const { access_token } = getToken() || {}
  const data = {
    access_token,
    name,
    private: false,
    auto_init: true,
  }
  return request.post('/api/v5/user/repos', data)
}

// 创建分支
export const newBranch = (user, branch_name = 'master', repo = 'my-note') => {
  const { access_token } = getToken() || {}
  const data = {
    access_token,
    refs: 'master',
    branch_name,
  }
  return request.post(`/api/v5/repos/${user.login}/${repo}`, data)
}

// 获取文件树
export const getTree = (user, repo = 'my-note') => {
  const { access_token } = getToken() || {}
  const sha = '4f26aeafdb2367620a393c973eddbe8f8b846ebd' // master
  return request.get(`/api/v5/repos/${user.login}/${repo}/git/trees/${sha}`, { params: { access_token, recursive: 1 } })
}

// 获取文件列表
export const getFiles = (user, path = '', repo = 'my-note') => {
  const { access_token } = getToken() || {}
  return request.get(`/api/v5/repos/${user.login}/${repo}/contents/${path}`, { params: { access_token } })
}

// 获取文件详情
export const getFile = (user, path = '', repo = 'my-note') => {
  const { access_token } = getToken() || {}
  return request.get(`/api/v5/repos/${user.login}/${repo}/contents/${path}`, { params: { access_token } })
}

// 新增文件
export const newFile = (user, content, path, repo = 'my-note') => {
  const { access_token } = getToken() || {}
  const data = {
    access_token,
    content: Base64.encode(content),
    message: new Date().toJSON(),
  }
  return request.post(`/api/v5/repos/${user.login}/${repo}/contents/${path}`, data)
}

// 新增目录, 其实就是新增一个 内容是 # 的 .gitignore 文件
export const newFolder = (user, path, repo = 'my-note') => {
  const filePath = `${path}/.gitignore`
  return newFile('#', filePath, user, repo)
}

// 更新文件
export const updateFile = (user, content, fileInfo) => {
  const { access_token } = getToken() || {}
  const { url, sha } = fileInfo
  const data = {
    access_token,
    content: Base64.encode(content),
    sha,
    message: new Date().toJSON(),
  }

  const filePath = url.replace(BASE_URL, '')

  return request.put(filePath, data)
}
